Class: CloudReactorAPIClient::WorkflowExecution

Inherits:
Object
  • Object
show all
Defined in:
lib/cloudreactor_api_client/models/workflow_execution.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ WorkflowExecution

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 149

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `CloudReactorAPIClient::WorkflowExecution` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `CloudReactorAPIClient::WorkflowExecution`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'uuid')
    self.uuid = attributes[:'uuid']
  end

  if attributes.key?(:'dashboard_url')
    self.dashboard_url = attributes[:'dashboard_url']
  end

  if attributes.key?(:'workflow')
    self.workflow = attributes[:'workflow']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'run_reason')
    self.run_reason = attributes[:'run_reason']
  end

  if attributes.key?(:'started_at')
    self.started_at = attributes[:'started_at']
  end

  if attributes.key?(:'started_by')
    self.started_by = attributes[:'started_by']
  end

  if attributes.key?(:'finished_at')
    self.finished_at = attributes[:'finished_at']
  end

  if attributes.key?(:'last_heartbeat_at')
    self.last_heartbeat_at = attributes[:'last_heartbeat_at']
  end

  if attributes.key?(:'stop_reason')
    self.stop_reason = attributes[:'stop_reason']
  end

  if attributes.key?(:'marked_done_at')
    self.marked_done_at = attributes[:'marked_done_at']
  end

  if attributes.key?(:'marked_done_by')
    self.marked_done_by = attributes[:'marked_done_by']
  end

  if attributes.key?(:'kill_started_at')
    self.kill_started_at = attributes[:'kill_started_at']
  end

  if attributes.key?(:'killed_by')
    self.killed_by = attributes[:'killed_by']
  end

  if attributes.key?(:'kill_finished_at')
    self.kill_finished_at = attributes[:'kill_finished_at']
  end

  if attributes.key?(:'kill_error_code')
    self.kill_error_code = attributes[:'kill_error_code']
  end

  if attributes.key?(:'failed_attempts')
    self.failed_attempts = attributes[:'failed_attempts']
  end

  if attributes.key?(:'timed_out_attempts')
    self.timed_out_attempts = attributes[:'timed_out_attempts']
  end

  if attributes.key?(:'workflow_snapshot')
    if (value = attributes[:'workflow_snapshot']).is_a?(Hash)
      self.workflow_snapshot = value
    end
  end

  if attributes.key?(:'workflow_task_instance_executions')
    if (value = attributes[:'workflow_task_instance_executions']).is_a?(Array)
      self.workflow_task_instance_executions = value
    end
  end

  if attributes.key?(:'workflow_transition_evaluations')
    if (value = attributes[:'workflow_transition_evaluations']).is_a?(Array)
      self.workflow_transition_evaluations = value
    end
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#created_atObject

Returns the value of attribute created_at.



65
66
67
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 65

def created_at
  @created_at
end

#dashboard_urlObject

Returns the value of attribute dashboard_url.



22
23
24
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 22

def dashboard_url
  @dashboard_url
end

#failed_attemptsObject

Returns the value of attribute failed_attempts.



55
56
57
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 55

def failed_attempts
  @failed_attempts
end

#finished_atObject

Returns the value of attribute finished_at.



35
36
37
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 35

def finished_at
  @finished_at
end

#kill_error_codeObject

Returns the value of attribute kill_error_code.



53
54
55
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 53

def kill_error_code
  @kill_error_code
end

#kill_finished_atObject

Returns the value of attribute kill_finished_at.



51
52
53
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 51

def kill_finished_at
  @kill_finished_at
end

#kill_started_atObject

Returns the value of attribute kill_started_at.



46
47
48
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 46

def kill_started_at
  @kill_started_at
end

#killed_byObject

Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.



49
50
51
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 49

def killed_by
  @killed_by
end

#last_heartbeat_atObject

Returns the value of attribute last_heartbeat_at.



37
38
39
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 37

def last_heartbeat_at
  @last_heartbeat_at
end

#marked_done_atObject

Returns the value of attribute marked_done_at.



41
42
43
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 41

def marked_done_at
  @marked_done_at
end

#marked_done_byObject

Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.



44
45
46
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 44

def marked_done_by
  @marked_done_by
end

#run_reasonObject

Returns the value of attribute run_reason.



28
29
30
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 28

def run_reason
  @run_reason
end

#started_atObject

Returns the value of attribute started_at.



30
31
32
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 30

def started_at
  @started_at
end

#started_byObject

Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.



33
34
35
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 33

def started_by
  @started_by
end

#statusObject

Returns the value of attribute status.



26
27
28
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 26

def status
  @status
end

#stop_reasonObject

Returns the value of attribute stop_reason.



39
40
41
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 39

def stop_reason
  @stop_reason
end

#timed_out_attemptsObject

Returns the value of attribute timed_out_attempts.



57
58
59
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 57

def timed_out_attempts
  @timed_out_attempts
end

#updated_atObject

Returns the value of attribute updated_at.



67
68
69
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 67

def updated_at
  @updated_at
end

#urlObject

Returns the value of attribute url.



18
19
20
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 18

def url
  @url
end

#uuidObject

Returns the value of attribute uuid.



20
21
22
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 20

def uuid
  @uuid
end

#workflowObject

Returns the value of attribute workflow.



24
25
26
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 24

def workflow
  @workflow
end

#workflow_snapshotObject

Returns the value of attribute workflow_snapshot.



59
60
61
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 59

def workflow_snapshot
  @workflow_snapshot
end

#workflow_task_instance_executionsObject

Returns the value of attribute workflow_task_instance_executions.



61
62
63
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 61

def workflow_task_instance_executions
  @workflow_task_instance_executions
end

#workflow_transition_evaluationsObject

Returns the value of attribute workflow_transition_evaluations.



63
64
65
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 63

def workflow_transition_evaluations
  @workflow_transition_evaluations
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



100
101
102
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 100

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 70

def self.attribute_map
  {
    :'url' => :'url',
    :'uuid' => :'uuid',
    :'dashboard_url' => :'dashboard_url',
    :'workflow' => :'workflow',
    :'status' => :'status',
    :'run_reason' => :'run_reason',
    :'started_at' => :'started_at',
    :'started_by' => :'started_by',
    :'finished_at' => :'finished_at',
    :'last_heartbeat_at' => :'last_heartbeat_at',
    :'stop_reason' => :'stop_reason',
    :'marked_done_at' => :'marked_done_at',
    :'marked_done_by' => :'marked_done_by',
    :'kill_started_at' => :'kill_started_at',
    :'killed_by' => :'killed_by',
    :'kill_finished_at' => :'kill_finished_at',
    :'kill_error_code' => :'kill_error_code',
    :'failed_attempts' => :'failed_attempts',
    :'timed_out_attempts' => :'timed_out_attempts',
    :'workflow_snapshot' => :'workflow_snapshot',
    :'workflow_task_instance_executions' => :'workflow_task_instance_executions',
    :'workflow_transition_evaluations' => :'workflow_transition_evaluations',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



514
515
516
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 514

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



135
136
137
138
139
140
141
142
143
144
145
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 135

def self.openapi_nullable
  Set.new([
    :'finished_at',
    :'last_heartbeat_at',
    :'stop_reason',
    :'marked_done_at',
    :'kill_started_at',
    :'kill_finished_at',
    :'kill_error_code',
  ])
end

.openapi_typesObject

Attribute type mapping.



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 105

def self.openapi_types
  {
    :'url' => :'String',
    :'uuid' => :'String',
    :'dashboard_url' => :'String',
    :'workflow' => :'NameAndUuid',
    :'status' => :'WorkflowExecutionStatus',
    :'run_reason' => :'Integer',
    :'started_at' => :'Time',
    :'started_by' => :'String',
    :'finished_at' => :'Time',
    :'last_heartbeat_at' => :'Time',
    :'stop_reason' => :'Integer',
    :'marked_done_at' => :'Time',
    :'marked_done_by' => :'String',
    :'kill_started_at' => :'Time',
    :'killed_by' => :'String',
    :'kill_finished_at' => :'Time',
    :'kill_error_code' => :'Integer',
    :'failed_attempts' => :'Integer',
    :'timed_out_attempts' => :'Integer',
    :'workflow_snapshot' => :'Hash<String, Object>',
    :'workflow_task_instance_executions' => :'Array<WorkflowTaskInstanceExecution>',
    :'workflow_transition_evaluations' => :'Array<WorkflowTransitionEvaluation>',
    :'created_at' => :'Time',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 470

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      url == o.url &&
      uuid == o.uuid &&
      dashboard_url == o.dashboard_url &&
      workflow == o.workflow &&
      status == o.status &&
      run_reason == o.run_reason &&
      started_at == o.started_at &&
      started_by == o.started_by &&
      finished_at == o.finished_at &&
      last_heartbeat_at == o.last_heartbeat_at &&
      stop_reason == o.stop_reason &&
      marked_done_at == o.marked_done_at &&
      marked_done_by == o.marked_done_by &&
      kill_started_at == o.kill_started_at &&
      killed_by == o.killed_by &&
      kill_finished_at == o.kill_finished_at &&
      kill_error_code == o.kill_error_code &&
      failed_attempts == o.failed_attempts &&
      timed_out_attempts == o.timed_out_attempts &&
      workflow_snapshot == o.workflow_snapshot &&
      workflow_task_instance_executions == o.workflow_task_instance_executions &&
      workflow_transition_evaluations == o.workflow_transition_evaluations &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 544

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = CloudReactorAPIClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



615
616
617
618
619
620
621
622
623
624
625
626
627
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 615

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 521

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


501
502
503
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 501

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



507
508
509
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 507

def hash
  [url, uuid, dashboard_url, workflow, status, run_reason, started_at, started_by, finished_at, last_heartbeat_at, stop_reason, marked_done_at, marked_done_by, kill_started_at, killed_by, kill_finished_at, kill_error_code, failed_attempts, timed_out_attempts, workflow_snapshot, workflow_task_instance_executions, workflow_transition_evaluations, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 267

def list_invalid_properties
  invalid_properties = Array.new
  if @url.nil?
    invalid_properties.push('invalid value for "url", url cannot be nil.')
  end

  if @uuid.nil?
    invalid_properties.push('invalid value for "uuid", uuid cannot be nil.')
  end

  if @dashboard_url.nil?
    invalid_properties.push('invalid value for "dashboard_url", dashboard_url cannot be nil.')
  end

  if @workflow.nil?
    invalid_properties.push('invalid value for "workflow", workflow cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if !@run_reason.nil? && @run_reason > 2147483647
    invalid_properties.push('invalid value for "run_reason", must be smaller than or equal to 2147483647.')
  end

  if !@run_reason.nil? && @run_reason < -2147483648
    invalid_properties.push('invalid value for "run_reason", must be greater than or equal to -2147483648.')
  end

  if @started_at.nil?
    invalid_properties.push('invalid value for "started_at", started_at cannot be nil.')
  end

  if @started_by.nil?
    invalid_properties.push('invalid value for "started_by", started_by cannot be nil.')
  end

  if !@stop_reason.nil? && @stop_reason > 2147483647
    invalid_properties.push('invalid value for "stop_reason", must be smaller than or equal to 2147483647.')
  end

  if !@stop_reason.nil? && @stop_reason < -2147483648
    invalid_properties.push('invalid value for "stop_reason", must be greater than or equal to -2147483648.')
  end

  if @marked_done_by.nil?
    invalid_properties.push('invalid value for "marked_done_by", marked_done_by cannot be nil.')
  end

  if @killed_by.nil?
    invalid_properties.push('invalid value for "killed_by", killed_by cannot be nil.')
  end

  if !@kill_error_code.nil? && @kill_error_code > 2147483647
    invalid_properties.push('invalid value for "kill_error_code", must be smaller than or equal to 2147483647.')
  end

  if !@kill_error_code.nil? && @kill_error_code < -2147483648
    invalid_properties.push('invalid value for "kill_error_code", must be greater than or equal to -2147483648.')
  end

  if !@failed_attempts.nil? && @failed_attempts > 2147483647
    invalid_properties.push('invalid value for "failed_attempts", must be smaller than or equal to 2147483647.')
  end

  if !@failed_attempts.nil? && @failed_attempts < -2147483648
    invalid_properties.push('invalid value for "failed_attempts", must be greater than or equal to -2147483648.')
  end

  if !@timed_out_attempts.nil? && @timed_out_attempts > 2147483647
    invalid_properties.push('invalid value for "timed_out_attempts", must be smaller than or equal to 2147483647.')
  end

  if !@timed_out_attempts.nil? && @timed_out_attempts < -2147483648
    invalid_properties.push('invalid value for "timed_out_attempts", must be greater than or equal to -2147483648.')
  end

  if @workflow_snapshot.nil?
    invalid_properties.push('invalid value for "workflow_snapshot", workflow_snapshot cannot be nil.')
  end

  if @workflow_task_instance_executions.nil?
    invalid_properties.push('invalid value for "workflow_task_instance_executions", workflow_task_instance_executions cannot be nil.')
  end

  if @workflow_transition_evaluations.nil?
    invalid_properties.push('invalid value for "workflow_transition_evaluations", workflow_transition_evaluations cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



591
592
593
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 591

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



597
598
599
600
601
602
603
604
605
606
607
608
609
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 597

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



585
586
587
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 585

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
# File 'lib/cloudreactor_api_client/models/workflow_execution.rb', line 370

def valid?
  return false if @url.nil?
  return false if @uuid.nil?
  return false if @dashboard_url.nil?
  return false if @workflow.nil?
  return false if @status.nil?
  return false if !@run_reason.nil? && @run_reason > 2147483647
  return false if !@run_reason.nil? && @run_reason < -2147483648
  return false if @started_at.nil?
  return false if @started_by.nil?
  return false if !@stop_reason.nil? && @stop_reason > 2147483647
  return false if !@stop_reason.nil? && @stop_reason < -2147483648
  return false if @marked_done_by.nil?
  return false if @killed_by.nil?
  return false if !@kill_error_code.nil? && @kill_error_code > 2147483647
  return false if !@kill_error_code.nil? && @kill_error_code < -2147483648
  return false if !@failed_attempts.nil? && @failed_attempts > 2147483647
  return false if !@failed_attempts.nil? && @failed_attempts < -2147483648
  return false if !@timed_out_attempts.nil? && @timed_out_attempts > 2147483647
  return false if !@timed_out_attempts.nil? && @timed_out_attempts < -2147483648
  return false if @workflow_snapshot.nil?
  return false if @workflow_task_instance_executions.nil?
  return false if @workflow_transition_evaluations.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  true
end