Class: CloudReactorAPIClient::WorkflowTransition

Inherits:
Object
  • Object
show all
Defined in:
lib/cloudreactor_api_client/models/workflow_transition.rb

Overview

A WorkflowTransition is a directed edge in a Worfklow, which is a directed graph. It contains a source WorkflowTaskInstance, a destination WorkflowTaskInstance, as well as conditions for triggering the destination to execution.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ WorkflowTransition

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/cloudreactor_api_client/models/workflow_transition.rb', line 107

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `CloudReactorAPIClient::WorkflowTransition` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `CloudReactorAPIClient::WorkflowTransition`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'uuid')
    self.uuid = attributes[:'uuid']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'from_workflow_task_instance')
    self.from_workflow_task_instance = attributes[:'from_workflow_task_instance']
  end

  if attributes.key?(:'to_workflow_task_instance')
    self.to_workflow_task_instance = attributes[:'to_workflow_task_instance']
  end

  if attributes.key?(:'rule_type')
    self.rule_type = attributes[:'rule_type']
  end

  if attributes.key?(:'exit_codes')
    if (value = attributes[:'exit_codes']).is_a?(Array)
      self.exit_codes = value
    end
  end

  if attributes.key?(:'threshold_property')
    self.threshold_property = attributes[:'threshold_property']
  end

  if attributes.key?(:'custom_expression')
    self.custom_expression = attributes[:'custom_expression']
  end

  if attributes.key?(:'priority')
    self.priority = attributes[:'priority']
  end

  if attributes.key?(:'ui_color')
    self.ui_color = attributes[:'ui_color']
  end

  if attributes.key?(:'ui_line_style')
    self.ui_line_style = attributes[:'ui_line_style']
  end

  if attributes.key?(:'ui_scale')
    self.ui_scale = attributes[:'ui_scale']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#created_atObject

Returns the value of attribute created_at.



45
46
47
# File 'lib/cloudreactor_api_client/models/workflow_transition.rb', line 45

def created_at
  @created_at
end

#custom_expressionObject

Returns the value of attribute custom_expression.



35
36
37
# File 'lib/cloudreactor_api_client/models/workflow_transition.rb', line 35

def custom_expression
  @custom_expression
end

#descriptionObject

Returns the value of attribute description.



23
24
25
# File 'lib/cloudreactor_api_client/models/workflow_transition.rb', line 23

def description
  @description
end

#exit_codesObject

Returns the value of attribute exit_codes.



31
32
33
# File 'lib/cloudreactor_api_client/models/workflow_transition.rb', line 31

def exit_codes
  @exit_codes
end

#from_workflow_task_instanceObject

Returns the value of attribute from_workflow_task_instance.



25
26
27
# File 'lib/cloudreactor_api_client/models/workflow_transition.rb', line 25

def from_workflow_task_instance
  @from_workflow_task_instance
end

#priorityObject

Returns the value of attribute priority.



37
38
39
# File 'lib/cloudreactor_api_client/models/workflow_transition.rb', line 37

def priority
  @priority
end

#rule_typeObject

Returns the value of attribute rule_type.



29
30
31
# File 'lib/cloudreactor_api_client/models/workflow_transition.rb', line 29

def rule_type
  @rule_type
end

#threshold_propertyObject

Returns the value of attribute threshold_property.



33
34
35
# File 'lib/cloudreactor_api_client/models/workflow_transition.rb', line 33

def threshold_property
  @threshold_property
end

#to_workflow_task_instanceObject

Returns the value of attribute to_workflow_task_instance.



27
28
29
# File 'lib/cloudreactor_api_client/models/workflow_transition.rb', line 27

def to_workflow_task_instance
  @to_workflow_task_instance
end

#ui_colorObject

Returns the value of attribute ui_color.



39
40
41
# File 'lib/cloudreactor_api_client/models/workflow_transition.rb', line 39

def ui_color
  @ui_color
end

#ui_line_styleObject

Returns the value of attribute ui_line_style.



41
42
43
# File 'lib/cloudreactor_api_client/models/workflow_transition.rb', line 41

def ui_line_style
  @ui_line_style
end

#ui_scaleObject

Returns the value of attribute ui_scale.



43
44
45
# File 'lib/cloudreactor_api_client/models/workflow_transition.rb', line 43

def ui_scale
  @ui_scale
end

#updated_atObject

Returns the value of attribute updated_at.



47
48
49
# File 'lib/cloudreactor_api_client/models/workflow_transition.rb', line 47

def updated_at
  @updated_at
end

#urlObject

Returns the value of attribute url.



19
20
21
# File 'lib/cloudreactor_api_client/models/workflow_transition.rb', line 19

def url
  @url
end

#uuidObject

Returns the value of attribute uuid.



21
22
23
# File 'lib/cloudreactor_api_client/models/workflow_transition.rb', line 21

def uuid
  @uuid
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



71
72
73
# File 'lib/cloudreactor_api_client/models/workflow_transition.rb', line 71

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/cloudreactor_api_client/models/workflow_transition.rb', line 50

def self.attribute_map
  {
    :'url' => :'url',
    :'uuid' => :'uuid',
    :'description' => :'description',
    :'from_workflow_task_instance' => :'from_workflow_task_instance',
    :'to_workflow_task_instance' => :'to_workflow_task_instance',
    :'rule_type' => :'rule_type',
    :'exit_codes' => :'exit_codes',
    :'threshold_property' => :'threshold_property',
    :'custom_expression' => :'custom_expression',
    :'priority' => :'priority',
    :'ui_color' => :'ui_color',
    :'ui_line_style' => :'ui_line_style',
    :'ui_scale' => :'ui_scale',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



352
353
354
# File 'lib/cloudreactor_api_client/models/workflow_transition.rb', line 352

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



97
98
99
100
101
102
103
# File 'lib/cloudreactor_api_client/models/workflow_transition.rb', line 97

def self.openapi_nullable
  Set.new([
    :'exit_codes',
    :'priority',
    :'ui_scale',
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/cloudreactor_api_client/models/workflow_transition.rb', line 76

def self.openapi_types
  {
    :'url' => :'String',
    :'uuid' => :'String',
    :'description' => :'String',
    :'from_workflow_task_instance' => :'NameAndUuid',
    :'to_workflow_task_instance' => :'NameAndUuid',
    :'rule_type' => :'RuleTypeEnum',
    :'exit_codes' => :'Array<String>',
    :'threshold_property' => :'ThresholdPropertyEnum',
    :'custom_expression' => :'String',
    :'priority' => :'Integer',
    :'ui_color' => :'String',
    :'ui_line_style' => :'String',
    :'ui_scale' => :'Float',
    :'created_at' => :'Time',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/cloudreactor_api_client/models/workflow_transition.rb', line 317

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      url == o.url &&
      uuid == o.uuid &&
      description == o.description &&
      from_workflow_task_instance == o.from_workflow_task_instance &&
      to_workflow_task_instance == o.to_workflow_task_instance &&
      rule_type == o.rule_type &&
      exit_codes == o.exit_codes &&
      threshold_property == o.threshold_property &&
      custom_expression == o.custom_expression &&
      priority == o.priority &&
      ui_color == o.ui_color &&
      ui_line_style == o.ui_line_style &&
      ui_scale == o.ui_scale &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
# File 'lib/cloudreactor_api_client/models/workflow_transition.rb', line 382

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = CloudReactorAPIClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'lib/cloudreactor_api_client/models/workflow_transition.rb', line 453

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/cloudreactor_api_client/models/workflow_transition.rb', line 359

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


339
340
341
# File 'lib/cloudreactor_api_client/models/workflow_transition.rb', line 339

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



345
346
347
# File 'lib/cloudreactor_api_client/models/workflow_transition.rb', line 345

def hash
  [url, uuid, description, from_workflow_task_instance, to_workflow_task_instance, rule_type, exit_codes, threshold_property, custom_expression, priority, ui_color, ui_line_style, ui_scale, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/cloudreactor_api_client/models/workflow_transition.rb', line 185

def list_invalid_properties
  invalid_properties = Array.new
  if @url.nil?
    invalid_properties.push('invalid value for "url", url cannot be nil.')
  end

  if @uuid.nil?
    invalid_properties.push('invalid value for "uuid", uuid cannot be nil.')
  end

  if !@description.nil? && @description.to_s.length > 5000
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 5000.')
  end

  if @from_workflow_task_instance.nil?
    invalid_properties.push('invalid value for "from_workflow_task_instance", from_workflow_task_instance cannot be nil.')
  end

  if @to_workflow_task_instance.nil?
    invalid_properties.push('invalid value for "to_workflow_task_instance", to_workflow_task_instance cannot be nil.')
  end

  if @rule_type.nil?
    invalid_properties.push('invalid value for "rule_type", rule_type cannot be nil.')
  end

  if !@custom_expression.nil? && @custom_expression.to_s.length > 5000
    invalid_properties.push('invalid value for "custom_expression", the character length must be smaller than or equal to 5000.')
  end

  if !@priority.nil? && @priority > 2147483647
    invalid_properties.push('invalid value for "priority", must be smaller than or equal to 2147483647.')
  end

  if !@priority.nil? && @priority < 0
    invalid_properties.push('invalid value for "priority", must be greater than or equal to 0.')
  end

  if !@ui_color.nil? && @ui_color.to_s.length > 16
    invalid_properties.push('invalid value for "ui_color", the character length must be smaller than or equal to 16.')
  end

  if !@ui_line_style.nil? && @ui_line_style.to_s.length > 50
    invalid_properties.push('invalid value for "ui_line_style", the character length must be smaller than or equal to 50.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



429
430
431
# File 'lib/cloudreactor_api_client/models/workflow_transition.rb', line 429

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



435
436
437
438
439
440
441
442
443
444
445
446
447
# File 'lib/cloudreactor_api_client/models/workflow_transition.rb', line 435

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



423
424
425
# File 'lib/cloudreactor_api_client/models/workflow_transition.rb', line 423

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/cloudreactor_api_client/models/workflow_transition.rb', line 244

def valid?
  return false if @url.nil?
  return false if @uuid.nil?
  return false if !@description.nil? && @description.to_s.length > 5000
  return false if @from_workflow_task_instance.nil?
  return false if @to_workflow_task_instance.nil?
  return false if @rule_type.nil?
  return false if !@custom_expression.nil? && @custom_expression.to_s.length > 5000
  return false if !@priority.nil? && @priority > 2147483647
  return false if !@priority.nil? && @priority < 0
  return false if !@ui_color.nil? && @ui_color.to_s.length > 16
  return false if !@ui_line_style.nil? && @ui_line_style.to_s.length > 50
  return false if @created_at.nil?
  return false if @updated_at.nil?
  true
end